@@ -36,6 +36,9 @@ struct __stdio_file {
 #define BUFLINEWISE 8
 #define NOBUF 16
 #define STATICBUF 32
+#define FDPIPE 64
+#define CANREAD 128
+#define CANWRITE 256
 
 #define _IONBF 0
 #define _IOLBF 1
@@ -71,6 +74,18 @@ int __fflush_stdin(void);
 int __fflush_stdout(void);
 int __fflush_stderr(void);
 
-FILE* __stdio_init_file(int fd,int closeonerror);
+FILE* __stdio_init_file(int fd,int closeonerror,int mode);
 int __stdio_parse_mode(const char *mode);
 void __stdio_flushall(void);
+
+#ifndef __THREAD_INTERNAL_H__
+int __libc_close(int fd);
+int __libc_open(const char*fn,int flags,...);
+int __libc_read(int fd,void*buf,int len);
+int __libc_write(int fd,const void*buf,int len);
+#endif
+
+FILE *fopen_unlocked(const char *path, const char *mode) __THROW;
+FILE *fdopen_unlocked(int fildes, const char *mode) __THROW;
+FILE *freopen_unlocked(const char *path, const char *mode, FILE *stream) __THROW;
+
