@@ -5,12 +5,15 @@
 #include <sys/types.h>
 #include <time.h>
 
+__BEGIN_DECLS
+
 struct utimbuf {
   time_t actime;  /* access time */
   time_t modtime; /* modification time */
 };
 
-int utime(const char *filename, struct utimbuf *buf) __THROW;
+int utime(const char* filename, struct utimbuf* buf) __THROW;
 
+__END_DECLS
 
 #endif
