@@ -31,7 +31,7 @@
 #define NULL ((void*)0)
 #endif
 
-typedef union {
+typedef struct {
   void*  next;
   size_t size;
 } __alloc_t;
