@@ -6,7 +6,7 @@ void* memcpy(void* dst, const void* src, size_t count) {
   register char *d=dst;
   register const char *s=src;
   ++count;	/* this actually produces better code than using count-- */
-  while (--count) {
+  while (__likely(--count)) {
     *d = *s;
     ++d; ++s;
   }
