@@ -1,14 +1,15 @@
 #include "dietfeatures.h"
+#include <sys/cdefs.h>
 
 int strcmp(register const char *s,register const char *t) {
   register char x;
 
   for (;;) {
-    x = *s; if (x != *t) break; if (!x) break; ++s; ++t;
+    x = *s; if (__unlikely(x != *t)) break; if (__unlikely(!x)) break; ++s; ++t;
 #ifndef WANT_SMALL_STRING_ROUTINES
-    x = *s; if (x != *t) break; if (!x) break; ++s; ++t;
-    x = *s; if (x != *t) break; if (!x) break; ++s; ++t;
-    x = *s; if (x != *t) break; if (!x) break; ++s; ++t;
+    x = *s; if (__unlikely(x != *t)) break; if (__unlikely(!x)) break; ++s; ++t;
+    x = *s; if (__unlikely(x != *t)) break; if (__unlikely(!x)) break; ++s; ++t;
+    x = *s; if (__unlikely(x != *t)) break; if (__unlikely(!x)) break; ++s; ++t;
 #endif
   }
   return ((int)(unsigned int)(unsigned char) x)
