@@ -2,12 +2,16 @@
 #include "dietstdio.h"
 #include <unistd.h>
 
-size_t fread( void *ptr, size_t size, size_t nmemb, FILE *stream) {
+size_t fread_unlocked(void *ptr, size_t size, size_t nmemb, FILE *stream) {
   int res;
   unsigned long i,j;
   j=size*nmemb;
   i=0;
 
+  if (!(stream->flags&CANREAD)) {
+    stream->flags|=ERRORINDICATOR;
+    return 0;
+  }
   if (!j || j/nmemb!=size) return 0;
   if (stream->ungotten) {
     stream->ungotten=0;
@@ -20,8 +24,8 @@ size_t fread( void *ptr, size_t size, size_t nmemb, FILE *stream) {
   if ( !(stream->flags&FDPIPE) && (j>stream->buflen)) {
     size_t tmp=j-i;
     int res;
-    fflush(stream);
-    while ((res=read(stream->fd,ptr+i,tmp))<(int)tmp) {
+    if (fflush_unlocked(stream)) return 0;
+    while ((res=__libc_read(stream->fd,ptr+i,tmp))<(int)tmp) {
       if (res==-1) {
 	stream->flags|=ERRORINDICATOR;
 	goto exit;
@@ -35,7 +39,7 @@ size_t fread( void *ptr, size_t size, size_t nmemb, FILE *stream) {
   }
 #endif
   for (; i<j; ++i) {
-    res=fgetc(stream);
+    res=fgetc_unlocked(stream);
     if (res==EOF)
 exit:
       return i/size;
@@ -44,3 +48,5 @@ exit:
   }
   return nmemb;
 }
+
+size_t fread(void *ptr, size_t size, size_t nmemb, FILE *stream) __attribute__((weak,alias("fread_unlocked")));
